@@ -1,7 +1,7 @@
 mat.dis <- function (align1, align2, sub.mat.id = "PAM250", gap = NULL) {
 
   if (!exists("sub.mat"))
-    data(sub.mat)
+    data("sub.mat", package = "bios2mds", verbose= FALSE)
 
   if (!is.element(sub.mat.id, names(sub.mat)))
     stop("sub.mat does not contain sub.mat.id")
